==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ListManagedClusterMonitoringUserCredentialsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property resourceName The name of the managed cluster resource.
 * @property serverFqdn server fqdn type for credentials to be returned
 */
public data class ListManagedClusterMonitoringUserCredentialsPlainArgs(
    public val resourceGroupName: String,
    public val resourceName: String,
    public val serverFqdn: String? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs =
        com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .resourceName(resourceName.let({ args0 -> args0 }))
            .serverFqdn(serverFqdn?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListManagedClusterMonitoringUserCredentialsPlainArgs].
 */
@PulumiTagMarker
public class ListManagedClusterMonitoringUserCredentialsPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var resourceName: String? = null

    private var serverFqdn: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("fsobwlvyxstylscl")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the managed cluster resource.
     */
    @JvmName("upxdrqjoofheefwi")
    public suspend fun resourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceName = mapped
    }

    /**
     * @param value server fqdn type for credentials to be returned
     */
    @JvmName("bnjlwlegtnkbpdib")
    public suspend fun serverFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.serverFqdn = mapped
    }

    internal fun build(): ListManagedClusterMonitoringUserCredentialsPlainArgs =
        ListManagedClusterMonitoringUserCredentialsPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            resourceName = resourceName ?: throw PulumiNullFieldException("resourceName"),
            serverFqdn = serverFqdn,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ListManagedClusterMonitoringUserCredentialsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property resourceName The name of the managed cluster resource.
 * @property serverFqdn server fqdn type for credentials to be returned
 */
public data class ListManagedClusterMonitoringUserCredentialsPlainArgs(
    public val resourceGroupName: String,
    public val resourceName: String,
    public val serverFqdn: String? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs =
        com.pulumi.azurenative.containerservice.inputs.ListManagedClusterMonitoringUserCredentialsPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .resourceName(resourceName.let({ args0 -> args0 }))
            .serverFqdn(serverFqdn?.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListManagedClusterMonitoringUserCredentialsPlainArgs].
 */
@PulumiTagMarker
public class ListManagedClusterMonitoringUserCredentialsPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var resourceName: String? = null

    private var serverFqdn: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mokvwgelyrxupurw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the managed cluster resource.
     */
    @JvmName("vkyngpbfxrlbofxx")
    public suspend fun resourceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceName = mapped
    }

    /**
     * @param value server fqdn type for credentials to be returned
     */
    @JvmName("jnemobwbvinhwyhx")
    public suspend fun serverFqdn(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.serverFqdn = mapped
    }

    internal fun build(): ListManagedClusterMonitoringUserCredentialsPlainArgs =
        ListManagedClusterMonitoringUserCredentialsPlainArgs(
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            resourceName = resourceName ?: throw PulumiNullFieldException("resourceName"),
            serverFqdn = serverFqdn,
        )
}
